Usage
CMplot(Pmap, col = c("red", "black", "green", "blue", "orange"), pch = 19,
band = 1, cir.band = 1, H = 1, ylim = NULL, cex.axis = 1, output = "b",
multracks = FALSE, cex = c(0.5, 1), r = 1, xlab = "Chromosome",
ylab = expression(-log[10](italic(p))), outward = TRUE, threshold = 0.01,
threshold.col="red", amplify = TRUE, signal.cex = 1.5, signal.pch = 19,
signal.col="red", cir.chr = TRUE, chr.band = 1, chr.col = NULL,
cir.labels = TRUE, plot0 = FALSE, fill.output=TRUE, fill = "jpg", dpi = 300)Arguments
Pmap
a dataframe, at least four columns. The first column is the name of SNP, the second column is the chromosome of SNP, the third column is the position of SNP, and the remaining columns are the P-value of each trait(Note:each trait a column)
col
a vector, the colour for each chromosome, the colours are not fixed, one, two, three or more colours can be used, if the length of the col is shorter than the length the chromosome, then colours will be applied circularly.the default: col=c("red", "black"
pch
a number, the type for the points, is the same with "pch" in band
a number, the space between chromosomes, the default is 1(if the band is 0, then there would be no space between chromosome)
cir.band
a number, the space between circles, the default is 1
H
a number, the height for each circle, each circle a trait, the default is 1
ylim
a vector, the range of Y-axis when plotting, is the same with "ylim" in cex.axis
a number, controls the size of labels of X-axis
output
a character, only "c" or "m" or "b" can be used. if plottype="c",only circle-Manhattan plot will be plotted; if plottype="m",only Manhattan plot will be plotted; if plottype="b",both circle-Manhattan and Manhattan plots will be plotted;
multracks
a logical,if multracks=FALSE, plotting rectangular Manhattan plot on only one track, if TRUE,it will make multiple tracks for the rectangular one
cex
a vector, the size for the points, is the same with "size" in , and the first number controls the size of points in circle plot(the default is 0.5), the second number controls the size of points in Manhattan plot(the default is 1) r
a number, the radius for the circle(the inside radius), the default is 1
xlab
a character, the labels for x axis.
ylab
a character, the labels for y axis.
outward
logical, if outward=TRUE,then all points will be plotted from inside to outside.
threshold
a number, users can adjust the significant level they wanted, if threshold=0 or =NULL, then the threshold line will not be added,the default is 0.01
threshold.col
a character, the colour for the line of threshold level
amplify
logical, CMplot can amplify the significant points, if amplify=T, then the points greater than significant level will be bigger than normal, the default: amplify=TRUE
signal.cex
a number, if amplify=TRUE, users can choose the size of significant points bigger than threshold.
signal.pch
a number, if amplify=TRUE, users can choose the shape of significant points bigger than threshold.
signal.col
a character, if amplify=TRUE, users can choose the colour of significant points bigger than threshold.
cir.chr
logical, a boundary represents chromosome, the default is TRUE
chr.band
a number, the width for the boundary, if cir.chr=FALSE, then this parameter will be useless.
chr.col
a character, the colour for the boundary, only one colour is allowed, if chr.col=NULL, then the default colours are the same with the parameter "col".
cir.labels
logical, whether to add the name of chromosome to the circle plot("S" means sex chromosome), the default: cir.labels=TRUE
plot0
logical, users can choose whether to plot the chromosome (written as 0) with no clear chr number in both Manhattan plot
fill.output
a logical, users can choose whether output the plot results
fill
a character, users can choose the different output type of plot, so for, "jpg","pdf","tiff" can be selected by users
dpi
a number, the picture element for .jpg and .tiff files